@@ -1,8 +1,11 @@
+# Copyright 2022 tkorays. All Rights Reserved.
+# Licensed to MIT under a Contributor Agreement.
+
 from datetime import datetime
 
 
 class DataPoint:
-    def __init__(self, name: str, timestamp: datetime, value: dict, tags: list, meta=dict):
+    def __init__(self, name: str, timestamp: datetime, value: dict, tags: list, meta: dict):
         """
         init a datapoint
 
